# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-06-16 10:30
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0004_merge_20200616_1011'),
        ('djangoldp_resource', '0003_resource_conversations'),
    ]

    operations = [
    ]
