# Generated by Django 2.2.18 on 2021-05-25 08:22

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0011_auto_20210525_1018'),
    ]

    operations = [
        migrations.AlterField(
            model_name='keyword',
            name='name',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Keywords'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='img',
            field=models.URLField(blank=True, default='http://localhost:8000/media/defaultresource.png', null=True, verbose_name='Illustration'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='name',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Resource Title'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='user',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='type',
            name='name',
            field=models.CharField(blank=True, max_length=50, null=True, verbose_name='Resource type'),
        ),
    ]
