# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-05-05 15:27
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_conversation', '0002_auto_20190917_1056'),
        ('djangoldp_resource', '0002_auto_20200426_1902'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='conversations',
            field=models.ManyToManyField(blank=True, related_name='resources', to='djangoldp_conversation.Conversation'),
        ),
    ]
