# Generated by Django 2.2.28 on 2022-10-12 13:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0012_auto_20210525_1022'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resource',
            name='link',
            field=models.CharField(blank=True, max_length=2048, null=True, verbose_name='Internet link'),
        ),
    ]
