# Generated by Django 2.2.18 on 2021-05-25 08:18

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0010_auto_20200923_1017'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='keyword',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='resource',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AlterModelOptions(
            name='type',
            options={'default_permissions': ['add', 'change', 'delete', 'view', 'control']},
        ),
        migrations.AddField(
            model_name='resource',
            name='creationDate',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
    ]
