# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2020-08-12 14:46
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0007_auto_20200709_1411'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resource',
            name='img',
            field=models.URLField(default='http://localhost:8000/media/defaultresource.png', verbose_name='Illustration'),
        ),
    ]
