# Generated by Django 2.2.16 on 2020-09-23 10:17

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0009_auto_20200812_1459'),
    ]

    operations = [
        migrations.AlterField(
            model_name='resource',
            name='circle',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='resources', to='djangoldp_circle.Circle'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='type',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='djangoldp_resource.Type', verbose_name='Resource type'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, to=settings.AUTH_USER_MODEL),
        ),
    ]
