# -*- coding: utf-8 -*-
# Generated by Django 1.11.27 on 2020-07-09 14:11
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('djangoldp_resource', '0006_auto_20200617_1458'),
    ]

    operations = [
        migrations.AddField(
            model_name='resource',
            name='circle',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='resources', to='djangoldp_circle.Circle'),
        ),
        migrations.AlterField(
            model_name='keyword',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AlterField(
            model_name='resource',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
        migrations.AlterField(
            model_name='type',
            name='is_backlink',
            field=models.BooleanField(default=False, help_text='set automatically to indicate the Model is a backlink'),
        ),
    ]
